@@ -1,10 +1,20 @@
 # -*- coding: utf-8 -*-
+from urlparse import urlsplit
 from django.db.models import signals
 from django.utils.thread_support import currentThread
 
 _urls_to_purge = {}
 
 def add_purge_url(url):
+    if url is None:
+        return
+
+    if isinstance(url, basestring):
+        parsed = urlsplit(url)
+        if parsed.scheme != '' or parsed.netloc != '':
+            # Only accept relative url, i.e. no 'http://...'
+            return
+
     _urls_to_purge.setdefault(currentThread(), set()).add(url)
 
 def get_urls():
