@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 from django.conf import settings
+from django.core.urlresolvers import get_script_prefix
 from django_cachepurge import clear_urls, get_urls
 from django_cachepurge.utils import pruneAsync
 
@@ -16,7 +17,11 @@ class CachePurge(object):
 
     def process_response(self, request, response):
 
+        prefix = get_script_prefix()
         for url in get_urls():
+            if url.startswith(prefix):
+                # convert absolute url into a relative one
+                url = url.replace(prefix, u'/', 1)
             for cache in CACHE_URLS:
                 url_in_cache = "%s%s" % (cache, url)
 
